# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'

%define _with_repolib 1

%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define repodir %{_javadir}/repository.jboss.com/juddi/%{verrel}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define section free

%define reltag rc5
%define verrel %{version}rc5

# To make the tarball:
# svn export http://svn.apache.org/repos/asf/webservices/juddi/tags/v2.0rc5 ws-juddi
# tar czf ws-juddi-2.0rc5.tgz ws-juddi

%define appdir  %{_localstatedir}/lib/%{name}/webapps
%define homedir %{_datadir}/%{name}

Name:		juddi
Summary:	Open source Java implementation UDDI specification.
Version: 	2.0
Release:	0.rc5.4jpp
Epoch:		0
URL: 		http://ws.apache.org/juddi/
License: 	APL
Group: 		Development/Libraries/Java
Source0: 	ws-juddi-2.0rc5.tgz
Source1:	juddi-component-info.xml
Source2:	%{name}-maven-depmap.xml

Patch0:     %{name}-skip-jdependandjxr.patch
Patch1:     %{name}-add-deps.patch

# Tagged build.xml file has wrong path for sql
BuildRequires:	jpackage-utils
BuildRequires:  maven2
BuildRequires:  maven2-plugin-assembly
BuildRequires:  maven2-plugin-clean
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-one
BuildRequires:  maven2-plugin-release
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven2-plugin-source
BuildRequires:  maven2-plugin-surefire
BuildRequires:  maven2-plugin-war
BuildRequires:	axis
BuildRequires:	jakarta-commons-logging
BuildRequires:	tomcat5-servlet-2.4-api
#Optional:	axis
Requires:	jakarta-commons-logging
Requires:	tomcat5-servlet-2.4-api
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root
BuildArch:	noarch

%description
jUDDI (pronounced "Judy") is an open source Java implementation 
of the Universal Description, Discovery, and Integration (UDDI) 
specification for Web Services.

Starting with 2.0rc5 SQL is no longer provided.
The sql files are now IN the jar, and the juddi.properties file contains

# jUDDI database creation
juddi.isCreateDatabase=true
juddi.tablePrefix=JUDDI_
juddi.databaseExistsSql=select * from ${prefix}BUSINESS_ENTITY
juddi.sqlFiles=juddi-sql/derby/create_database.sql,juddi-sql/insert_publishers.sql

to have the schema be created on first use.

Also note that you can now set a table prefix.

Starting with 2.0rc5 SQL is no longer provided.
An EAR is not provided as it can be easily created from the WAR

%if %{with_repolib}
%package	 repolib
Summary:	 Artifacts to be uploaded to a repository library
Group:	Development/Libraries/Java

%description	 repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio
%endif

%package javadoc
Group:          Development/Documentation
Summary:        Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%package manual
Group:          Development/Documentation
Summary:        Javadoc for %{name}

%description manual
Manual for %{name}.

%package webapps
Group:		Development/Libraries
Summary:	WAR file for jUDDI.
#PreReq:		%{name} = %{epoch}:%{version}-%{release}
Requires:	axis
Requires:	jakarta-commons-logging
Requires:	tomcat5-servlet-2.4-api

%description webapps
The Web Archive (war) file for %{name}.

%prep
%setup -q -n ws-juddi
find . -name '*.jar' | xargs rm

%patch0
%patch1

mkdir externals
build-jar-repository lib \
	axis/axis \
    axis/jaxrpc \
    axis/saaj \
	jakarta-commons-logging \
    servletapi5 \

sed -i 's/@VERSION@/%{version}%{reltag}-brew/g' %{SOURCE1}
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{SOURCE1}

%build
unset CLASSPATH
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p $MAVEN_REPO_LOCAL

mvn-jpp \
        -e \
        -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        package javadoc:javadoc


%install
rm -rf $RPM_BUILD_ROOT

# *ars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}/juddi
install -m 644 juddi/target/juddi-%{verrel}.jar \
    $RPM_BUILD_ROOT%{_javadir}/juddi/juddi-%{verrel}.jar
ln -s juddi-%{verrel}.jar \
    $RPM_BUILD_ROOT%{_javadir}/juddi/juddi.jar

install -m 644 juddi/target/juddi-%{verrel}-sources.jar \
    $RPM_BUILD_ROOT%{_javadir}/juddi/juddi-%{verrel}-sources.jar
ln -s juddi-%{verrel}-sources.jar \
    $RPM_BUILD_ROOT%{_javadir}/juddi/juddi-sources.jar

install -m 644 juddi-client/target/juddi-client-%{verrel}.jar \
    $RPM_BUILD_ROOT%{_javadir}/juddi/juddi-client-%{verrel}.jar
ln -s juddi-client-%{verrel}.jar \
    $RPM_BUILD_ROOT%{_javadir}/juddi/juddi-client.jar

install -m 644 juddi-web/target/juddi.war \
    $RPM_BUILD_ROOT%{_javadir}/juddi/juddi-%{verrel}.war
ln -s juddi-%{verrel}.war \
    $RPM_BUILD_ROOT%{_javadir}/juddi/juddi.war

install -d -m 755 $RPM_BUILD_ROOT%{appdir}

# webapps
mv juddi-web/target/juddi/* $RPM_BUILD_ROOT%{appdir}

# /usr/share/juddi
install -d -m 755 $RPM_BUILD_ROOT/%{homedir}
pushd $RPM_BUILD_ROOT%{homedir}
	[ -d webapps ] || ln -fs %{appdir} webapps
popd

# documentation
install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -pr docs/* \
    $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/juddi
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/juddi-client
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

cp -pr juddi/target/site/apidocs/* \
    $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/juddi
cp -pr juddi-client/target/site/apidocs/* \
    $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/juddi-client


%if %{with_repolib}
	install -d -m 755 $RPM_BUILD_ROOT%{repodir}
	install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
	install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{repodir}/component-info.xml
	install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
	cp $RPM_BUILD_ROOT%{_javadir}/juddi/juddi.jar $RPM_BUILD_ROOT%{repodirlib}
	cp $RPM_BUILD_ROOT%{_javadir}/juddi/juddi-sources.jar $RPM_BUILD_ROOT%{repodirlib}
        cp $RPM_BUILD_ROOT%{_javadir}/juddi/juddi-client.jar $RPM_BUILD_ROOT%{repodirlib}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -s %{name}-%{version} %{_javadocdir}/%{name}

%postun javadoc
if [ "$1" = "0" ]; then
    rm -f %{_javadocdir}/%{name}
fi

%files
%defattr(0644,root,root,0755)
%{_javadir}/juddi/*.jar

%files webapps
%defattr(0644,root,root,0755)
%{_javadir}/juddi/*.war
%{appdir}
%dir %{homedir}/webapps

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%ghost %doc %{_javadocdir}/%{name}

%files manual
%defattr(0644,root,root,0755)
%{_docdir}/%{name}-%{version}

%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{repodir}
%endif

%changelog
* Wed Dec 19 2007 Fernando Nasser <fnasser@redhat.com> 0:2.0-0.rc5.4jpp
- Add missing maven-releated dependencies

* Wed Dec 19 2007 Deepak Bhole <dbhole@redhat.com> 0:2.0-0.rc5.3jpp
- Proper mavenization
- Add perhaps most of necessary dependencies

* Wed Dec 19 2007 Fernando Nasser <fnasser@redhat.com> 0:2.0-0.rc5.2jpp
- Build with maven
- Remove deprecated apps subpackage
- Remove the '.' before the reltag as this component does not use one

* Wed Dec 19 2007 Fernando Nasser <fnasser@redhat.com> 0:2.0-0.rc5.1jpp
- Upgrade to RC5 (the version was renumbered to 2.0 to match spec)
- Remove deprecated sql subpackage

* Tue Mar 13 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:0.9-0.rc4.2jpp.ep1.2
- Fix repolib location

* Mon Mar 12 2007 Fernando Nasser <fnasser@redhat.com> 0:0.9-0.rc4.2jpp.ep1.1
- Make axis optional for juddi as it may be used in other containers

* Tue Feb 20 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:0.9-0.rc4.2jpp.el4ep1.2
- Add -brew suffix
- Export juddi.war in repolib

* Sat Feb 17 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:0.9-0.rc4.2jpp.el4ep1.1
- Add repolib support

* Wed Dec 07 2005 Fernando Nasser <fnasser@redhat.com> 0:0.9-0.rc4.2jpp_1rh
- Merge with upstream

* Wed Dec 07 2005 Fernando Nasser <fnasser@redhat.com> 0:0.9-0.rc4.2jpp
- First JPP 1.7 build

* Fri Jul 22 2005 Deepak Bhole <dbhole@redhat.com> 0:0.9-0.rc4.1jpp_3rh
- Removed the -b option from the patch directive as it is unnecessary.

* Thu Jul 21 2005 Deepak Bhole <dbhole@redhat.com> 0:0.9-0.rc4.1jpp_2rh
- Cleaned up spec file.
- Removed spurious dependency from apps and webapps on the main package.

* Tue Jul 19 2005 Deepak Bhole <dbhole@redhat.com> 0:0.9-0.rc4.1jpp_1rh
- First Red Hat build

* Mon Jul 18 2005 Deepak Bhole <dbhole@redhat.com> 0:0.9-0.rc4.1jpp
- Initial build.
